import re

from .preprocessing import text_preprocessing

stop_words = ['ada',
              'adalah',
              'adanya',
              'adapun',
              'agak',
              'agaknya',
              'agar',
              'akan',
              'akankah',
              'akhir',
              'akhiri',
              'akhirnya',
              'aku',
              'akulah',
              'amat',
              'amatlah',
              'anda',
              'andalah',
              'antar',
              'antara',
              'antaranya',
              'apa',
              'apaan',
              'apabila',
              'apakah',
              'apalagi',
              'apatah',
              'artinya',
              'asal',
              'asalkan',
              'atas',
              'atau',
              'ataukah',
              'ataupun',
              'awal',
              'awalnya',
              'bagai',
              'bagaikan',
              'bagaimana',
              'bagaimanakah',
              'bagaimanapun',
              'bagi',
              'bagian',
              'bahkan',
              'bahwa',
              'bahwasanya',
              'baik',
              'bakal',
              'bakalan',
              'balik',
              'banyak',
              'bapak',
              'baru',
              'bawah',
              'beberapa',
              'begini',
              'beginian',
              'beginikah',
              'beginilah',
              'begitu',
              'begitukah',
              'begitulah',
              'begitupun',
              'bekerja',
              'belakang',
              'belakangan',
              'belum',
              'belumlah',
              'benar',
              'benarkah',
              'benarlah',
              'berada',
              'berakhir',
              'berakhirlah',
              'berakhirnya',
              'berapa',
              'berapakah',
              'berapalah',
              'berapapun',
              'berarti',
              'berawal',
              'berbagai',
              'berdatangan',
              'beri',
              'berikan',
              'berikut',
              'berikutnya',
              'berjumlah',
              'berkali-kali',
              'berkata',
              'berkehendak',
              'berkeinginan',
              'berkenaan',
              'berlainan',
              'berlalu',
              'berlangsung',
              'berlebihan',
              'bermacam',
              'bermacam-macam',
              'bermaksud',
              'bermula',
              'bersama',
              'bersama-sama',
              'bersiap',
              'bersiap-siap',
              'bertanya',
              'bertanya-tanya',
              'berturut',
              'berturut-turut',
              'bertutur',
              'berujar',
              'berupa',
              'besar',
              'betul',
              'betulkah',
              'biasa',
              'biasanya',
              'bila',
              'bilakah',
              'bisa',
              'bisakah',
              'boleh',
              'bolehkah',
              'bolehlah',
              'buat',
              'bukan',
              'bukankah',
              'bukanlah',
              'bukannya',
              'bulan',
              'bung',
              'cara',
              'caranya',
              'cukup',
              'cukupkah',
              'cukuplah',
              'cuma',
              'dahulu',
              'dalam',
              'dan',
              'dapat',
              'dari',
              'daripada',
              'datang',
              'dekat',
              'demi',
              'demikian',
              'demikianlah',
              'dengan',
              'depan',
              'di',
              'dia',
              'diakhiri',
              'diakhirinya',
              'dialah',
              'diantara',
              'diantaranya',
              'diberi',
              'diberikan',
              'diberikannya',
              'dibuat',
              'dibuatnya',
              'didapat',
              'didatangkan',
              'digunakan',
              'diibaratkan',
              'diibaratkannya',
              'diingat',
              'diingatkan',
              'diinginkan',
              'dijawab',
              'dijelaskan',
              'dijelaskannya',
              'dikarenakan',
              'dikatakan',
              'dikatakannya',
              'dikerjakan',
              'diketahui',
              'diketahuinya',
              'dikira',
              'dilakukan',
              'dilalui',
              'dilihat',
              'dimaksud',
              'dimaksudkan',
              'dimaksudkannya',
              'dimaksudnya',
              'diminta',
              'dimintai',
              'dimisalkan',
              'dimulai',
              'dimulailah',
              'dimulainya',
              'dimungkinkan',
              'dini',
              'dipastikan',
              'diperbuat',
              'diperbuatnya',
              'dipergunakan',
              'diperkirakan',
              'diperlihatkan',
              'diperlukan',
              'diperlukannya',
              'dipersoalkan',
              'dipertanyakan',
              'dipunyai',
              'diri',
              'dirinya',
              'disampaikan',
              'disebut',
              'disebutkan',
              'disebutkannya',
              'disini',
              'disinilah',
              'ditambahkan',
              'ditandaskan',
              'ditanya',
              'ditanyai',
              'ditanyakan',
              'ditegaskan',
              'ditujukan',
              'ditunjuk',
              'ditunjuki',
              'ditunjukkan',
              'ditunjukkannya',
              'ditunjuknya',
              'dituturkan',
              'dituturkannya',
              'diucapkan',
              'diucapkannya',
              'diungkapkan',
              'dong',
              'dua',
              'dulu',
              'empat',
              'enggak',
              'enggaknya',
              'entah',
              'entahlah',
              'guna',
              'gunakan',
              'hal',
              'hampir',
              'hanya',
              'hanyalah',
              'hari',
              'harus',
              'haruslah',
              'harusnya',
              'hendak',
              'hendaklah',
              'hendaknya',
              'hingga',
              'ia',
              'ialah',
              'ibarat',
              'ibaratkan',
              'ibaratnya',
              'ibu',
              'ikut',
              'ingat',
              'ingat-ingat',
              'ingin',
              'inginkah',
              'inginkan',
              'ini',
              'inikah',
              'inilah',
              'itu',
              'itukah',
              'itulah',
              'jadi',
              'jadilah',
              'jadinya',
              'jangan',
              'jangankan',
              'janganlah',
              'jauh',
              'jawab',
              'jawaban',
              'jawabnya',
              'jelas',
              'jelaskan',
              'jelaslah',
              'jelasnya',
              'jika',
              'jikalau',
              'juga',
              'jumlah',
              'jumlahnya',
              'justru',
              'kala',
              'kalau',
              'kalaulah',
              'kalaupun',
              'kalian',
              'kami',
              'kamilah',
              'kamu',
              'kamulah',
              'kan',
              'kapan',
              'kapankah',
              'kapanpun',
              'karena',
              'karenanya',
              'kasus',
              'kata',
              'katakan',
              'katakanlah',
              'katanya',
              'ke',
              'keadaan',
              'kebetulan',
              'kecil',
              'kedua',
              'keduanya',
              'keinginan',
              'kelamaan',
              'kelihatan',
              'kelihatannya',
              'kelima',
              'keluar',
              'kembali',
              'kemudian',
              'kemungkinan',
              'kemungkinannya',
              'kenapa',
              'kepada',
              'kepadanya',
              'kesampaian',
              'keseluruhan',
              'keseluruhannya',
              'keterlaluan',
              'ketika',
              'khususnya',
              'kini',
              'kinilah',
              'kira',
              'kira-kira',
              'kiranya',
              'kita',
              'kitalah',
              'kok',
              'kurang',
              'lagi',
              'lagian',
              'lah',
              'lain',
              'lainnya',
              'lalu',
              'lama',
              'lamanya',
              'lanjut',
              'lanjutnya',
              'lebih',
              'lewat',
              'lima',
              'luar',
              'macam',
              'maka',
              'makanya',
              'makin',
              'malah',
              'malahan',
              'mampu',
              'mampukah',
              'mana',
              'manakala',
              'manalagi',
              'masa',
              'masalah',
              'masalahnya',
              'masih',
              'masihkah',
              'masing',
              'masing-masing',
              'mau',
              'maupun',
              'melainkan',
              'melakukan',
              'melalui',
              'melihat',
              'melihatnya',
              'memang',
              'memastikan',
              'memberi',
              'memberikan',
              'membuat',
              'memerlukan',
              'memihak',
              'meminta',
              'memintakan',
              'memisalkan',
              'memperbuat',
              'mempergunakan',
              'memperkirakan',
              'memperlihatkan',
              'mempersiapkan',
              'mempersoalkan',
              'mempertanyakan',
              'mempunyai',
              'memulai',
              'memungkinkan',
              'menaiki',
              'menambahkan',
              'menandaskan',
              'menanti',
              'menanti-nanti',
              'menantikan',
              'menanya',
              'menanyai',
              'menanyakan',
              'mendapat',
              'mendapatkan',
              'mendatang',
              'mendatangi',
              'mendatangkan',
              'menegaskan',
              'mengakhiri',
              'mengapa',
              'mengatakan',
              'mengatakannya',
              'mengenai',
              'mengerjakan',
              'mengetahui',
              'menggunakan',
              'menghendaki',
              'mengibaratkan',
              'mengibaratkannya',
              'mengingat',
              'mengingatkan',
              'menginginkan',
              'mengira',
              'mengucapkan',
              'mengucapkannya',
              'mengungkapkan',
              'menjadi',
              'menjawab',
              'menjelaskan',
              'menuju',
              'menunjuk',
              'menunjuki',
              'menunjukkan',
              'menunjuknya',
              'menurut',
              'menuturkan',
              'menyampaikan',
              'menyangkut',
              'menyatakan',
              'menyebutkan',
              'menyeluruh',
              'menyiapkan',
              'merasa',
              'mereka',
              'merekalah',
              'merupakan',
              'meski',
              'meskipun',
              'meyakini',
              'meyakinkan',
              'minta',
              'mirip',
              'misal',
              'misalkan',
              'misalnya',
              'mula',
              'mulai',
              'mulailah',
              'mulanya',
              'mungkin',
              'mungkinkah',
              'nah',
              'naik',
              'namun',
              'nanti',
              'nantinya',
              'nyaris',
              'nyatanya',
              'oleh',
              'olehnya',
              'pada',
              'padahal',
              'padanya',
              'pak',
              'paling',
              'panjang',
              'pantas',
              'para',
              'pasti',
              'pastilah',
              'penting',
              'pentingnya',
              'per',
              'percuma',
              'perlu',
              'perlukah',
              'perlunya',
              'pernah',
              'persoalan',
              'pertama',
              'pertama-tama',
              'pertanyaan',
              'pertanyakan',
              'pihak',
              'pihaknya',
              'pukul',
              'pula',
              'pun',
              'punya',
              'rasa',
              'rasanya',
              'rata',
              'rupanya',
              'saat',
              'saatnya',
              'saja',
              'sajalah',
              'saling',
              'sama',
              'sama-sama',
              'sambil',
              'sampai',
              'sampai-sampai',
              'sampaikan',
              'sana',
              'sangat',
              'sangatlah',
              'satu',
              'saya',
              'sayalah',
              'se',
              'sebab',
              'sebabnya',
              'sebagai',
              'sebagaimana',
              'sebagainya',
              'sebagian',
              'sebaik',
              'sebaik-baiknya',
              'sebaiknya',
              'sebaliknya',
              'sebanyak',
              'sebegini',
              'sebegitu',
              'sebelum',
              'sebelumnya',
              'sebenarnya',
              'seberapa',
              'sebesar',
              'sebetulnya',
              'sebisanya',
              'sebuah',
              'sebut',
              'sebutlah',
              'sebutnya',
              'secara',
              'secukupnya',
              'sedang',
              'sedangkan',
              'sedemikian',
              'sedikit',
              'sedikitnya',
              'seenaknya',
              'segala',
              'segalanya',
              'segera',
              'seharusnya',
              'sehingga',
              'seingat',
              'sejak',
              'sejauh',
              'sejenak',
              'sejumlah',
              'sekadar',
              'sekadarnya',
              'sekali',
              'sekali-kali',
              'sekalian',
              'sekaligus',
              'sekalipun',
              'sekarang',
              'sekarang',
              'sekecil',
              'seketika',
              'sekiranya',
              'sekitar',
              'sekitarnya',
              'sekurang-kurangnya',
              'sekurangnya',
              'sela',
              'selain',
              'selaku',
              'selalu',
              'selama',
              'selama-lamanya',
              'selamanya',
              'selanjutnya',
              'seluruh',
              'seluruhnya',
              'semacam',
              'semakin',
              'semampu',
              'semampunya',
              'semasa',
              'semasih',
              'semata',
              'semata-mata',
              'semaunya',
              'sementara',
              'semisal',
              'semisalnya',
              'sempat',
              'semua',
              'semuanya',
              'semula',
              'sendiri',
              'sendirian',
              'sendirinya',
              'seolah',
              'seolah-olah',
              'seorang',
              'sepanjang',
              'sepantasnya',
              'sepantasnyalah',
              'seperlunya',
              'seperti',
              'sepertinya',
              'sepihak',
              'sering',
              'seringnya',
              'serta',
              'serupa',
              'sesaat',
              'sesama',
              'sesampai',
              'sesegera',
              'sesekali',
              'seseorang',
              'sesuatu',
              'sesuatunya',
              'sesudah',
              'sesudahnya',
              'setelah',
              'setempat',
              'setengah',
              'seterusnya',
              'setiap',
              'setiba',
              'setibanya',
              'setidak-tidaknya',
              'setidaknya',
              'setinggi',
              'seusai',
              'sewaktu',
              'siap',
              'siapa',
              'siapakah',
              'siapapun',
              'sini',
              'sinilah',
              'soal',
              'soalnya',
              'suatu',
              'sudah',
              'sudahkah',
              'sudahlah',
              'supaya',
              'tadi',
              'tadinya',
              'tahu',
              'tahun',
              'tak',
              'tambah',
              'tambahnya',
              'tampak',
              'tampaknya',
              'tandas',
              'tandasnya',
              'tanpa',
              'tanya',
              'tanyakan',
              'tanyanya',
              'tapi',
              'tegas',
              'tegasnya',
              'telah',
              'tempat',
              'tengah',
              'tentang',
              'tentu',
              'tentulah',
              'tentunya',
              'tepat',
              'terakhir',
              'terasa',
              'terbanyak',
              'terdahulu',
              'terdapat',
              'terdiri',
              'terhadap',
              'terhadapnya',
              'teringat',
              'teringat-ingat',
              'terjadi',
              'terjadilah',
              'terjadinya',
              'terkira',
              'terlalu',
              'terlebih',
              'terlihat',
              'termasuk',
              'ternyata',
              'tersampaikan',
              'tersebut',
              'tersebutlah',
              'tertentu',
              'tertuju',
              'terus',
              'terutama',
              'tetap',
              'tetapi',
              'tiap',
              'tiba',
              'tiba-tiba',
              'tidak',
              'tidakkah',
              'tidaklah',
              'tiga',
              'tinggi',
              'toh',
              'tunjuk',
              'turut',
              'tutur',
              'tuturnya',
              'ucap',
              'ucapnya',
              'ujar',
              'ujarnya',
              'umum',
              'umumnya',
              'ungkap',
              'ungkapnya',
              'untuk',
              'usah',
              'usai',
              'waduh',
              'wah',
              'wahai',
              'waktu',
              'waktunya',
              'walau',
              'walaupun',
              'wong',
              'yaitu',
              'yakin',
              'yakni',
              'yang']  # Daftar stop words

df_new_kamusalay = {'anakjakartaasikasik': 'anak jakarta asyik asyik',
                    'pakcikdahtua': 'pak cik sudah tua',
                    'pakcikmudalagi': 'pak cik muda lagi',
                    't3tapjokowi': 'tetap jokowi',
                    '3x': 'tiga kali',
                    'aamiin': 'amin',
                    'aamiinn': 'amin',
                    'aamin': 'amin',
                    'aammiin': 'amin',
                    'abis': 'habis',
                    'abisin': 'habiskan',
                    'acau': 'kacau',
                    'achok': 'ahok',
                    'ad': 'ada',
                    'adek': 'adik',
                    'adl': 'adalah',
                    'adlah': 'adalah',
                    'adlh': 'adalah',
                    'ado': 'ada',
                    'aduhh': 'aduh',
                    'aer': 'air',
                    'afdol': 'afdal',
                    'agamaataualqur': 'agama alquran',
                    'agm': 'agama',
                    'agma': 'agama',
                    'ahaha': 'haha',
                    'ahahaha': 'haha',
                    'ahehehehe': 'hehe',
                    'ahir': 'akhir',
                    'ahirnya': 'akhirnya',
                    'ahk': 'ahok',
                    'ahlamdulillah': 'alhamdulillah',
                    'ahli2': 'para ahli',
                    'ahlusunnah': 'ahlus sunah',
                    'ahmaddani': 'ahmad dhani',
                    'aho': 'ahok',
                    'ahoax': 'ahok',
                    'ahoaxx': 'ahok',
                    'ahog': 'ahok',
                    'ahokataudjarot': 'ahok djarot',
                    'ahokbebanijokowi': 'ahok beban jokowi',
                    'ahokbtp': 'ahok basuki tjahaja purnama',
                    'ahokditolakwarga': 'ahok ditolak warga',
                    'ahokdjarot': 'ahok djarot',
                    'ahokdjarotterbukti': 'ahok djarot terbukti',
                    'ahokers': 'ahoker',
                    'ahokfighter': 'ahok pejuang',
                    'ahokforpresident': 'ahok for presiden',
                    'ahokisthebest': 'ahok terbaik',
                    'ahokjarot': 'ahok djarot',
                    'ahokk': 'ahok',
                    'ahokmasukbui': 'ahok masuk bui',
                    'ahokmeskipun': 'ahok meskipun',
                    'ahokpositifjadi': 'ahok positif jadi',
                    'ahoksatuputaran': 'ahok satu putaran',
                    'ahoksemangat': 'ahok semangat',
                    'ahoktersangka': 'ahok tersangka',
                    'ahokterzhalimi': 'ahok terzalimi',
                    'ahoktetap': 'ahok tetap',
                    'ahoktidaksendiri': 'ahok tidak sendiri',
                    'ahokUSER': 'ahok',
                    'ahook': 'ahok',
                    'ahox': 'ahok',
                    'aing': 'aku',
                    'airmata': 'air mata',
                    'aiskrim': 'es krim',
                    'aj': 'saja',
                    'aja': 'saja',
                    'ajaa': 'saja',
                    'ajah': 'saja',
                    'ajalah': 'sajalah',
                    'aje': 'saja',
                    'ajg': 'anjing',
                    'ajh': 'saja',
                    'ajib': 'hebat',
                    'ajj': 'saja',
                    'ak': 'aku',
                    'akalakalan': 'akal akalan',
                    'akalakaln': 'akal akalan',
                    'akankena': 'akan kena',
                    'akherat': 'akhirat',
                    'akhi': 'saudara',
                    'akhirny': 'akhirnya',
                    'akhirnyamush': 'akhirnya musuh',
                    'akirnya': 'akhirnya',
                    'akn': 'akan',
                    'akoh': 'aku',
                    'aksiaksi1120aksi112020aksi1120': 'aksi aksi',
                    'akumuslim': 'aku muslim',
                    'akuwa': 'aqua',
                    'alahuakbar': 'allahu akbar',
                    'alallohu': 'alallahu',
                    'alesan': 'alasan',
                    'alhamdulilah': 'alhamdulillah',
                    'alhamdulillaah': 'alhamdulillah',
                    'alhamdullilah': 'alhamdulillah',
                    'alhmdllh': 'alhamdulillah',
                    'allahuakbar': 'allahu akbar',
                    'allahughayatuna': 'allahu ghayatuna',
                    'alloh': 'allah',
                    'allohu': 'allahu',
                    'alqur': 'alquran',
                    'ama': 'sama',
                    'amaca': 'ah masa',
                    'amajing': 'luar biasa',
                    'amcaman': 'ancaman',
                    'amiin': 'amin',
                    'aminn': 'amin',
                    'ampe': 'sampai',
                    'amriki': 'amerika',
                    'amuh': 'kamu',
                    'ana': 'saya',
                    'anbiarkekinian': 'biar kekinian',
                    'ancen': 'memang',
                    'ancur': 'hancur',
                    'ancuur': 'hancur',
                    'ane': 'saya',
                    'aneh2': 'aneh aneh',
                    'anget': 'hangat',
                    'angktpn': 'angkatpun',
                    'anjeng': 'anjing',
                    'anjg': 'anjing',
                    'ank': 'anak',
                    'anomaly': 'anomali',
                    'antikorupsi': 'anti korupsi',
                    'antum': 'kalian',
                    'anugrah': 'anugerah',
                    'ap': 'apa',
                    'apa2': 'apa apa',
                    'apaapaan': 'apa apaan',
                    'apaapalah': 'apa sajalah',
                    'apah': 'apa',
                    'apakabar': 'apa kabar',
                    'apalg': 'apa lagi',
                    'apamaunya': 'apa maunya',
                    'apane': 'apanya',
                    'apaoun': 'apapun',
                    'apasih': 'apa sih',
                    'ape': 'apa',
                    'apenista': 'penista',
                    'aph': 'apa',
                    'apk': 'apakah',
                    'aplgi': 'apa lagi',
                    'apo': 'apa',
                    'apose': 'apa sih',
                    'apz': 'apa',
                    'aq': 'aku',
                    'aquh': 'aku',
                    'artinx': 'artinya',
                    'asek': 'asyik',
                    'aseng': 'asing',
                    'asew': 'anjing',
                    'asik': 'asyik',
                    'ask': 'tanya',
                    'asline': 'aslinya',
                    'assalamualaikumalhamdulillahhasil': 'assalamualaykum alhamdulillah hasil',
                    'assalamuallaikum': 'assalamualaykum',
                    'asu': 'anjing',
                    'asw': 'anjing',
                    'asyek': 'asyik',
                    'atauatau05atauatau0atauatau0': 'atau',
                    'atauatauatau': 'atau',
                    'atauatauatau201atauatau201atauatauatau201atauatau': 'atau',
                    'atauatauatauatau': 'atau',
                    'atauatauatauatauatauatauatauatauatauatau': 'atau',
                    'atauem': 'atau',
                    'atauhr': 'atau',
                    'ataus': 'atau',
                    'ati': 'hati',
                    'ati2': 'hati hati',
                    'atit': 'sakit',
                    'ato': 'atau',
                    'atribut2': 'atribut atribut',
                    'atu': 'satu',
                    'atw': 'atau',
                    'awkeren': 'keren',
                    'awutawutan': 'awut awutan',
                    'aya': 'ada',
                    'ayang': 'sayang',
                    'ayok': 'ayo',
                    'ayoo': 'ayo',
                    'ayosavepakahok': 'ayo lindungi pak ahok',
                    'ayuk': 'ayo',
                    'aza': 'saja',
                    'azhan': 'azan',
                    'babeh': 'ayah',
                    'badboy': 'bad boy',
                    'badjingan': 'bajingan',
                    'bae': 'baik',
                    'bagaimnpun': 'bagaimana',
                    'bagi2': 'bagi bagi',
                    'bagimane': 'bagaimana',
                    'bahwasannya': 'bahwasanya',
                    'bakalan': 'akan',
                    'balaikota': 'balai kota',
                    'bales': 'balas',
                    'balikin': 'kembalikan',
                    'baliq': 'balig',
                    'bandarq': 'bandarku',
                    'banding2in': 'membanding bandingkan',
                    'bandingin': 'bandingkan',
                    'banga': 'bangsa',
                    'banged': 'banget',
                    'bangen': 'banget',
                    'bangett': 'banget',
                    'bangettt': 'banget',
                    'bangke': 'bangkai',
                    'bangsag': 'bangsat',
                    'bangst': 'bangsat',
                    'bantuk': 'bentuk',
                    'banun': 'bangun',
                    'banyak2': 'perbanyak',
                    'banyakin': 'perbanyak',
                    'bapake': 'ayahnya',
                    'baper': 'bawa perasaan',
                    'baryaw': 'sabar ya',
                    'baryw': 'sabar ya',
                    'baso': 'bakso',
                    'basukibtp': 'basuki tjahaja purnama',
                    'basukigameover': 'basuki kalah',
                    'bat': 'banget',
                    'bauu': 'bau',
                    'bawak': 'bawa',
                    'bay': 'selamat tinggal',
                    'bayangin': 'bayangkan',
                    'bayaranatausuruhan': 'bayaran atau suruhan',
                    'bbrapa': 'beberapa',
                    'bbrp': 'beberapa',
                    'bc': 'baca',
                    'bct': 'bacot',
                    'bda': 'beda',
                    'bdan': 'badan',
                    'bdg': 'bandung',
                    'bdn': 'badan',
                    'becanda': 'bercanda',
                    'bedoa': 'berdoa',
                    'bedua': 'berdua',
                    'bege': 'bego',
                    'bejad': 'bejat',
                    'bekel': 'bekal',
                    'bekingin': 'lindungi',
                    'belaislambelaislambelaislam': 'bela islam',
                    'belaquran': 'bela alquran',
                    'beliin': 'belikan',
                    'belom': 'belum',
                    'belon': 'belum',
                    'benar2': 'benar benar',
                    'bener': 'benar',
                    'bener2': 'benar benar',
                    'beneran': 'benaran',
                    'berantem': 'bertengkar',
                    'berdo': 'berdoa',
                    'berenti': 'berhenti',
                    'berfikir': 'berpikir',
                    'bergengam': 'bergenggam',
                    'bergoncang': 'berguncang',
                    'berindak': 'bertindak',
                    'beritadan': 'berita dan',
                    'beritain': 'memberitakan',
                    'beritany': 'beritanya',
                    'beritaterkini': 'berita kini',
                    'berkacaberkacanya': 'berkaca kaca',
                    'berrti': 'berarti',
                    'bersyukrlah': 'bersyukurlah',
                    'beruk2': 'beruk beruk',
                    'besoq': 'besok',
                    'bet': 'banget',
                    'bete': 'sebal',
                    'betulin': 'betulkan',
                    'beud': 'banget',
                    'beut': 'banget',
                    'bg': 'bagi',
                    'bgd': 'banget',
                    'bgerak': 'bergerak',
                    'bget': 'banget',
                    'bgi': 'bagi',
                    'bgini': 'begini',
                    'bgitu': 'begitu',
                    'bgks': 'bungkus',
                    'bgm': 'bagaimana',
                    'bgmn': 'bagaimana',
                    'bgmna': 'bagaimana',
                    'bgn': 'bangun',
                    'bgni': 'begini',
                    'bgntdr': 'bangun tidur',
                    'bgs': 'bagus',
                    'bgst': 'bangsat',
                    'bgt': 'banget',
                    'bgtu': 'begitu',
                    'bgus': 'bagus',
                    'bhay': 'selamat tinggal',
                    'bhinekaan': 'bhineka',
                    'bhinneka': 'bhineka',
                    'bhkan': 'bahkan',
                    'bhn': 'bahan',
                    'bhong': 'bohong',
                    'bhs': 'bahas',
                    'bhw': 'bahwa',
                    'bhwa': 'bahwa',
                    'bhy': 'bahaya',
                    'biarin': 'biarkan',
                    'biarpn': 'biarpun',
                    'bijimane': 'bagaimana',
                    'bisenye': 'bisanya',
                    'bistu': 'habis itu',
                    'bisya': 'bisa',
                    'biza': 'bisa',
                    'bj': 'baju',
                    'bju': 'baju',
                    'bk': 'buku',
                    'bkan': 'bukan',
                    'bkap': 'ayah',
                    'bkin': 'bikin',
                    'bkl': 'bakal',
                    'bkn': 'bukan',
                    'bkna': 'bukannya',
                    'bkp': 'ayah',
                    'bkr': 'bakar',
                    'bks': 'bungkus',
                    'bl': 'beli',
                    'blajar': 'belajar',
                    'blakan': 'blak',
                    'blg': 'bilang',
                    'blh': 'boleh',
                    'bli': 'beli',
                    'blik': 'balik',
                    'blingsatanya': 'belingsatan',
                    'bljr': 'belajar',
                    'blk': 'balik',
                    'blkg': 'belakang',
                    'blkng': 'belakang',
                    'blkngny': 'belakangnya',
                    'blm': 'belum',
                    'bln': 'bulan',
                    'blng': 'bilang',
                    'blngn': 'bilangan',
                    'blom': 'belum',
                    'blon': 'belum',
                    'bloon': 'belum',
                    'bls': 'balas',
                    'blum': 'belum',
                    'blusukan': 'blusuk',
                    'bndg': 'bandung',
                    'bndr': 'bandar',
                    'bner': 'benar',
                    'bneran': 'benar',
                    'bnget': 'banget',
                    'bngks': 'bungkus',
                    'bngng': 'bingung',
                    'bngsa': 'bangsa',
                    'bngt': 'banget',
                    'bngun': 'bangun',
                    'bnr': 'benar',
                    'bnrbnr': 'benar benar',
                    'bnrn': 'benaran',
                    'bntar': 'sebentar',
                    'bntr': 'sebentar',
                    'bnyak': 'banyak',
                    'bnyk': 'banyak',
                    'bnykny': 'banyaknya',
                    'bobo': 'tidur',
                    'bobok': 'tidur',
                    'bodo': 'bodoh',
                    'bokap': 'ayah',
                    'bokaps': 'ayah',
                    'bokapz': 'ayah',
                    'bole': 'boleh',
                    'boong': 'bohong',
                    'bosen': 'bosan',
                    'boskuh': 'bosku',
                    'boten': 'tidak',
                    'bozen': 'bosan',
                    'bozn': 'bosan',
                    'bp': 'bapak',
                    'bpak': 'bapak',
                    'bpk': 'bapak',
                    'br': 'baru',
                    'brani': 'berani',
                    'brantas': 'berantas',
                    'brapa': 'berapa',
                    'brarti': 'berarti',
                    'brasa': 'berasa',
                    'bravoo': 'bravo',
                    'breake': 'istirahat',
                    'breaking': 'istirahat',
                    'brengsek': 'berengsek',
                    'brg': 'barang',
                    'brgkt': 'berangkat',
                    'brharap': 'berharap',
                    'brhsl': 'berhasil',
                    'brikut': 'berikut',
                    'bringas': 'beringas',
                    'brisik': 'berisik',
                    'brjln': 'berjalan',
                    'brjuang': 'berjuang',
                    'brkeliaran': 'berkeliaran',
                    'brkfst': 'sarapan',
                    'brkpntingan': 'berkepentingan',
                    'brkumandang': 'berkumandang',
                    'brmslh': 'bermasalah',
                    'brngkt': 'berangkat',
                    'brp': 'berapa',
                    'brpa': 'berapa',
                    'brpedoman': 'berpedoman',
                    'brrti': 'berarti',
                    'brs': 'beres',
                    'brsal': 'berasal',
                    'brsama': 'bersama',
                    'brsamamu': 'bersamamu',
                    'brshbt': 'bersahabat',
                    'brsm': 'bersama',
                    'brtahan': 'bertahan',
                    'brthn': 'bertahan',
                    'brtmn': 'berteman',
                    'bru': 'baru',
                    'bruh': 'buruh',
                    'bryaw': 'sabar ya',
                    'bryw': 'sabar ya',
                    'bs': 'bisa',
                    'bsa': 'bisa',
                    'bsk': 'besok',
                    'bsok': 'besok',
                    'bsoq': 'besok',
                    'bsr': 'besar',
                    'bte': 'bosan',
                    'btg': 'batang',
                    'bth': 'butuh',
                    'btl': 'betul',
                    'btul': 'betul',
                    'btull': 'betul',
                    'buad': 'buat',
                    'buatapa': 'buat apa',
                    'buatin': 'buatkan',
                    'bubarin': 'bubarkan',
                    'bukabukaan': 'buka bukaan',
                    'bukane': 'bukannya',
                    'bukn': 'bukan',
                    'buktiin': 'buktikan',
                    'buktikan': 'buktikan',
                    'buktikqn': 'buktikan',
                    'bul': 'kibul',
                    'bulshit': 'kibul',
                    'buryam': 'bubur ayam',
                    'buzer': 'buzzer',
                    'buzzerahoaxsebarkanhoax': 'buzzer ahok sebar hoaks',
                    'buzzerbuzzernya': 'buzzer buzzernya',
                    'bw': 'bawa',
                    'bwa': 'bawa',
                    'bwaanx': 'bawaan',
                    'bwh': 'bawah',
                    'bwt': 'buat',
                    'byak': 'banyak',
                    'byk': 'banyak',
                    'bynk': 'banyak',
                    'byr': 'bayar',
                    'bzen': 'bosan',
                    'bzn': 'bosan',
                    'cabut': 'pergi',
                    'cagubnya': 'calon gubernurnya',
                    'cahya': 'cahaya',
                    'caiank': 'sayang',
                    'caiyo': 'semangat',
                    'cakep': 'cakap',
                    'cantek': 'cantik',
                    'capek': 'cape',
                    'caturx': 'catur',
                    'cayo': 'semangat',
                    'cb': 'coba',
                    'cecunguk2nya': 'cecunguk cecunguknya',
                    'ceheheheh': 'hehe',
                    'cekola': 'sekolah',
                    'cekolah': 'sekolah',
                    'celalaw': 'selalu',
                    'celalu': 'selalu',
                    'cemen': 'takut',
                    'cemplungin': 'mencemplungkan',
                    'cemungudh': 'semangat',
                    'cemungut': 'semangat',
                    'cemunguth': 'semangat',
                    'centuryataumuniratauhambalang': 'century munir atau hambalang',
                    'cepat2': 'cepat cepat',
                    'cepet': 'cepat',
                    'ceplas': 'ceplos',
                    'ceppat': 'cepat',
                    'cewe': 'cewek',
                    'ciamik': 'indah',
                    'ciap': 'siap',
                    'ciayou': 'semangat',
                    'cibuq': 'sibuk',
                    'cie': 'wah',
                    'ciee': 'wah',
                    'cini': 'sini',
                    'cino': 'cina',
                    'citizens': 'warga kota',
                    'ciyan': 'kasihan',
                    'ciye': 'wah',
                    'ciyus': 'serius',
                    'ckck': 'wkwk',
                    'ckp': 'cukup',
                    'ckrg': 'sekarang',
                    'ckup': 'cukup',
                    'cling': 'bersih',
                    'cll': 'selalu',
                    'cllu': 'selalu',
                    'cllw': 'selalu',
                    'cm': 'cuma',
                    'cma': 'cuma',
                    'cman': 'cuma',
                    'cmn': 'cuma',
                    'cmpk': 'cempaka',
                    'col': 'keren',
                    'compares': 'membandingkan',
                    'congrats': 'selamat',
                    'congratulation': 'selamat',
                    'corruptions': 'korupsi',
                    'corruptors': 'koruptor',
                    'cowo': 'cowok',
                    'coz': 'soalnya',
                    'cpat': 'cepat',
                    'cpe': 'cape',
                    'cpee': 'cape',
                    'cpet': 'cepat',
                    'cpt': 'cepat',
                    'cptn': 'cepatan',
                    'crt': 'cerita',
                    'crying': 'menangis',
                    'cs': 'rekan',
                    'cth': 'contoh',
                    'cukupsatuputaran': 'cukup satu putaran',
                    'cuman': 'cuma',
                    'cw': 'cewek',
                    'cwe': 'cewek',
                    'cwo': 'cowok',
                    'd': 'di',
                    'da': 'dan',
                    'dah': 'sudah',
                    'dalah': 'adalah',
                    'dalem': 'dalam',
                    'dann': 'dan',
                    'dapa': 'ada apa',
                    'dapah': 'ada apa',
                    'dapet': 'dapat',
                    'dapetin': 'mendapatkan',
                    'daripaddatidda': 'dari pada tidak',
                    'datangin': 'mendatangi',
                    'dateng': 'datang',
                    'daut': 'daud',
                    'dblg': 'dibilang',
                    'dblkng': 'dibelakang',
                    'dbls': 'dibalas',
                    'dbwt': 'dibuat',
                    'dbyr': 'dibayar',
                    'ddpn': 'di depan',
                    'dduk': 'duduk',
                    'de': 'deh',
                    'demen': 'suka',
                    'democrazy': 'demokrasi gila',
                    'demodemo': 'demo demo',
                    'demodemonov': 'demo november',
                    'denger': 'dengar',
                    'dengn': 'dengan',
                    'depa': 'depan',
                    'des': 'desember',
                    'dewadewa': 'dewa dewa',
                    'dftr': 'daftar',
                    'dg': 'dengan',
                    'dgn': 'dengan',
                    'dgr': 'dengar',
                    'dgrn': 'dengarkan',
                    'dh': 'sudah',
                    'dhewan': 'dewan',
                    'diaa': 'dia',
                    'diajakin': 'diajak',
                    'dianutny': 'dianutnya',
                    'diapain': 'diapakan',
                    'dibelakanghari': 'di belakang hari',
                    'dibiarin': 'dibiarkan',
                    'dibobongin': 'dibodohi',
                    'dibodohin': 'dibodohi',
                    'dibohongin': 'dibohongi',
                    'dibohonginataudibodohin': 'dibohongi atau dibodohi',
                    'diboongin': 'dibohongi',
                    'dibuatx': 'dibuatnya',
                    'dibudigunawankan': 'di budi gunawankan',
                    'dicuekin': 'dicueki',
                    'didenger': 'didengar',
                    'didengerin': 'didengarkan',
                    'didiemin': 'didiamkan',
                    'didlam': 'di dalam',
                    'didzalimi': 'dizalimi',
                    'die': 'dia',
                    'diem': 'diam',
                    'diem2': 'diam diam',
                    'digembosin': 'digembosi',
                    'diginiin': 'dibeginikan',
                    'dijadiin': 'dijadikan',
                    'dijatohin': 'dijatuhi',
                    'dijdkn': 'dijadikan',
                    'dikenyataanya': 'pada kenyataannya',
                    'dikirain': 'dikiranya',
                    'dikit': 'sedikit',
                    'dimance': 'di mana',
                    'dimandose': 'di mana sih',
                    'dimans': 'dimana',
                    'dimonitoring': 'dipantau',
                    'dinaikin': 'dinaiki',
                    'dinegri': 'di negeri',
                    'dipake': 'dipakai',
                    'dipemjara': 'di penjara',
                    'diperes': 'diperas',
                    'dipikirin': 'dipikirkan',
                    'dipilkada': 'di pilkada',
                    'diprose': 'diproses',
                    'dirix': 'dirinya',
                    'dirmh': 'di rumah',
                    'disalahgunakan': 'disalah gunakan',
                    'disamarinda': 'di samarinda',
                    'disewotin': 'disewoti',
                    'disumpahdisumpahin': 'disumpahi',
                    'ditemenin': 'ditemani',
                    'ditentukn': 'ditentukan',
                    'ditetapknnya': 'ditetapkan',
                    'ditrsangkakan': 'ditersangkakan',
                    'dittapkn': 'ditetapkan',
                    'diyem': 'diam',
                    'dizhalimi': 'dizalimi',
                    'dizholimi': 'dizalimi',
                    'dizolimi': 'dizalimi',
                    'djakarta': 'di jakarta',
                    'djasatuputaran': 'di satu putaran',
                    'djkt': 'di jakarta',
                    'djl': 'di jalan',
                    'djln': 'di jalan',
                    'djmin': 'dijamin',
                    'dkat': 'dekat',
                    'dket': 'dekat',
                    'dkijakarta': 'dki jakarta',
                    'dkls': 'di kelas',
                    'dkmps': 'di kampus',
                    'dkmr': 'di kamar',
                    'dkntr': 'di kantor',
                    'dksh': 'dikasih',
                    'dkt': 'dekat',
                    'dl': 'dulu',
                    'dlm': 'dalam',
                    'dlmnya': 'dalamnya',
                    'dlrng': 'dilarang',
                    'dlu': 'dulu',
                    'dluan': 'duluan',
                    'dmana': 'di mana',
                    'dmkn': 'dimakan',
                    'dmn': 'di mana',
                    'dmna': 'di mana',
                    'dmnmn': 'di mana mana',
                    'dmny': 'di mana',
                    'dn': 'dan',
                    'dng': 'dengan',
                    'dngan': 'dengan',
                    'dngar': 'dengar',
                    'dnger': 'dengar',
                    'dngerin': 'dengarkan',
                    'dngn': 'dengan',
                    'dngr': 'dengar',
                    'doain': 'doakan',
                    'doank': 'doang',
                    'doi': 'dia',
                    'dongok': 'dungu',
                    'donlot': 'unduh',
                    'dont': 'do not',
                    'doyan': 'suka',
                    'dp': 'uang muka',
                    'dpan': 'depan',
                    'dpet': 'dapat',
                    'dpk': 'depok',
                    'dpkrkn': 'dipikirkan',
                    'dpn': 'depan',
                    'dpnrmh': 'di depan rumah',
                    'dpt': 'dapat',
                    'dr': 'dari',
                    'drg': 'dokter gigi',
                    'drh': 'darah',
                    'dri': 'dari',
                    'drmh': 'di rumah',
                    'drmn': 'dari mana',
                    'drpd': 'daripada',
                    'drtd': 'dari tadi',
                    'drumah': 'di rumah',
                    'dsar': 'dasar',
                    'dsb': 'dan sebagainya',
                    'dsblh': 'di sebelah',
                    'dsini': 'di sini',
                    'dsklh': 'di sekolah',
                    'dsni': 'di sini',
                    'dsnii': 'di sini',
                    'dst': 'dan seterusnya',
                    'dtetapak': 'ditetapkan',
                    'dtg': 'datang',
                    'dtgn': 'datang',
                    'dtgny': 'datangnya',
                    'dtmbh': 'di tambah',
                    'dtmpt': 'di tempat',
                    'dtng': 'datang',
                    'dttapkn': 'ditetapkan',
                    'dtuntut': 'dituntun',
                    'duabelas': 'dua belas',
                    'duaduanya': 'dua duanya',
                    'duchh': 'aduh',
                    'duh': 'aduh',
                    'duit2': 'duit duit',
                    'dukungahok': 'dukung ahok',
                    'dukungfatwa': 'dukung fatwa',
                    'dukungfatwamui': 'dukung fatwa mui',
                    'duluan': 'lebih dahulu',
                    'duluw': 'dahulu',
                    'dunk': 'dong',
                    'durung': 'belum',
                    'dy': 'dia',
                    'dya': 'dia',
                    'dzolim': 'zalim',
                    'dzolimi': 'dizalimi',
                    'ea': 'iya',
                    'eagles': 'elang',
                    'ealah': 'iyalah',
                    'ech': 'eh',
                    'eehh': 'eh',
                    'egak': 'tidak',
                    'egh': 'eh',
                    'ehh': 'eh',
                    'ekong': 'kakek',
                    'elech': 'alah',
                    'elee': 'alah',
                    'elektibilitas': 'elektabilitas',
                    'elit': 'elite',
                    'elo': 'kamu',
                    'elu': 'kamu',
                    'eman': 'sayang',
                    'emang': 'memang',
                    'emangnya': 'memangnya',
                    'emank': 'memang',
                    'emg': 'memang',
                    'emng': 'memang',
                    'en': 'dan',
                    'ending': 'akhir',
                    'endingnya': 'akhirnya',
                    'engga': 'tidak',
                    'enggak': 'tidak',
                    'enjarakanahok': 'penjarakan ahok',
                    'enk': 'enak',
                    'entar': 'nanti',
                    'ente': 'kamu',
                    'entee': 'kamu',
                    'erti': 'mengerti',
                    'esbeye': 'susilo bambang yudhoyono',
                    'eskrim': 'es krim',
                    'eteb': 'bosan',
                    'everythings': 'segalanya',
                    'faham': 'paham',
                    'fanati': 'fanatik',
                    'fb': 'facebook',
                    'fcked': 'fuck',
                    'fears': 'fear',
                    'feb': 'februari',
                    'fikir': 'pikir',
                    'fikiran': 'pikiran',
                    'finah': 'fitnah',
                    'follback': 'ikuti',
                    'follbek': 'ikuti',
                    'followback': 'ikuti',
                    'follower': 'pengikut',
                    'followers': 'pengikut',
                    'freeahok': 'free ahok',
                    'futures': 'masa depan',
                    'g': 'tidak',
                    'ga': 'tidak',
                    'gaada': 'tidak ada',
                    'gabakal': 'tidak akan',
                    'gaberani': 'tidak berani',
                    'gabisa': 'tidak bisa',
                    'gaboleh': 'tidak boleh',
                    'gabut': 'kurang kerjaan',
                    'gada': 'tidak ada',
                    'gaenak': 'tidak enak',
                    'gaikut': 'tidak ikut',
                    'gajadi': 'tidak jadi',
                    'gajelas': 'tidak jelas',
                    'gak': 'tidak',
                    'gakuat': 'tidak kuat',
                    'gakz': 'tidak',
                    'galak2': 'galak galak',
                    'galo': 'galau',
                    'gamasuk': 'tidak masuk',
                    'gamau': 'tidak mau',
                    'ganbate': 'semangat',
                    'ganyangahok': 'ganyang ahok',
                    'ganyangcina': 'ganyang cina',
                    'gapake': 'tidak pakai',
                    'gapapa': 'tidak apa apa',
                    'gapapalah': 'tidak apalah',
                    'gapape': 'tidak apa',
                    'gapedulisamastatus': 'tidak peduli dengan status',
                    'gapernah': 'tidak pernah',
                    'gapunya': 'tidak punya',
                    'gara2': 'gara gara',
                    'garangangarangan': 'garang',
                    'garem': 'garam',
                    'gasuka': 'tidak suka',
                    'gatau': 'tak tau',
                    'gataw': 'tak tau',
                    'gatel': 'gatal',
                    'gausah': 'tidak usah',
                    'gawe': 'kerja',
                    'gbr': 'gambar',
                    'gdg': 'gudang',
                    'gece': 'gerak cepat',
                    'gelaja': 'gejala',
                    'gelarperkarasudahdiumumkan': 'gelar perkara sudah umum',
                    'gelik': 'geli',
                    'gelo': 'gila',
                    'gemes': 'gemas',
                    'gengges': 'ganggu',
                    'genks': 'geng',
                    'gera': 'gerak',
                    'gerja': 'gereja',
                    'ggl': 'gagal',
                    'ghiy': 'lagi',
                    'gi': 'lagi',
                    'gilak': 'gila',
                    'gile': 'gila',
                    'gilla': 'gila',
                    'gimana': 'bagaimana',
                    'gimanapun': 'bagaimanapun',
                    'gin': 'begini',
                    'ginian': 'beginian',
                    'gitu': 'begitu',
                    'gituan': 'begitu',
                    'gituh': 'begitu',
                    'gk': 'tidak',
                    'gmana': 'bagaimana',
                    'gmbr': 'gambar',
                    'gmn': 'bagaimana',
                    'gmna': 'bagaimana',
                    'gmpg': 'gampang',
                    'gmpng': 'gampang',
                    'gni': 'begini',
                    'gnti': 'ganti',
                    'goblog': 'goblok',
                    'goblog2in': 'goblok goblokin',
                    'going': 'pergi',
                    'gonna': 'pergi',
                    'gosipin': 'menggosipkan',
                    'gov': 'gubernur',
                    'governo': 'gubernur',
                    'governoor': 'gubernur',
                    'governor': 'gubernur',
                    'governour': 'gubernur',
                    'govt': 'pemerintah',
                    'goyangin': 'goyangkan',
                    'gpl': 'tidak pakai lama',
                    'gpny': 'tidak punya',
                    'gpp': 'tidak apa apa',
                    'gprnh': 'tidak pernah',
                    'gr': 'gede rasa',
                    'gr2': 'gara gara',
                    'gratisan': 'gratis',
                    'gregetan': 'geregetan',
                    'gt': 'begitu',
                    'gtu': 'begitu',
                    'gtw': 'tak tau',
                    'gua': 'gue',
                    'gub': 'gubernur',
                    'gubatauwalkot': 'gubernur atau walikota',
                    'gubenur': 'gubernur',
                    'guberenur': 'gubernur',
                    'guemewek': 'gue mewek',
                    'guoblog': 'goblok',
                    'gurbenur': 'gubernur',
                    'guwe': 'gue',
                    'gw': 'gue',
                    'gwe': 'gue',
                    'gws': 'semoga lekas sembuh',
                    'gx': 'tidak',
                    'ha': 'apa',
                    'habaib': 'habib',
                    'hacur': 'hancur',
                    'hadeh': 'aduh',
                    'hadeuh': 'aduh',
                    'hahaha': 'haha',
                    'hahahahaha': 'haha',
                    'hapal': 'hafal',
                    'hape': 'telepon genggam',
                    'happening': 'terjadi',
                    'haq': 'hak',
                    'haqq': 'hakiki',
                    'hariharimu': 'hari harimu',
                    'harini': 'hari ini',
                    'haritoleransiinternasional': 'hari toleransi internasional',
                    'haritoleransinasional': 'hari toleransi nasional',
                    'hastag': 'tagar',
                    'hastage': 'tagar',
                    'haters': 'hater',
                    'hatinye': 'hatinya',
                    'hbd': 'selamat ulang tahun',
                    'hbis': 'habis',
                    'hbng': 'hubungi',
                    'hbngn': 'hubungan',
                    'hbs': 'habis',
                    'hbskn': 'habiskan',
                    'hdup': 'hidup',
                    'hebatx': 'hebatnya',
                    'helow': 'halo',
                    'hepi': 'senang',
                    'hepihepinya': 'senang senangnya',
                    'hera': 'heran',
                    'hestag': 'tagar',
                    'hestagnya': 'tagarnya',
                    'hesteg': 'tagar',
                    'hestek': 'tagar',
                    'hgga': 'hingga',
                    'hha': 'haha',
                    'hhaaa': 'haha',
                    'hidupgwselo': 'hidup saya santai',
                    'hilangin': 'hilangkan',
                    'hkm': 'hukum',
                    'hkum': 'hukum',
                    'hlg': 'hilang',
                    'hlm': 'halaman',
                    'hlmn': 'halaman',
                    'hmm': 'hem',
                    'hny': 'hanya',
                    'hnya': 'hanya',
                    'hoak': 'hoaks',
                    'hoaker': 'penyebar hoaks',
                    'hoakers': 'penyebar hoaks',
                    'hog': 'ahok',
                    'hok': 'ahok',
                    'hopeless': 'putus asa',
                    'hormatin': 'hormati',
                    'hotels': 'hotel',
                    'hr': 'hari',
                    'hrapan': 'harapan',
                    'hrg': 'harga',
                    'hrgny': 'harganya',
                    'hri': 'hari',
                    'hrs': 'harus',
                    'hrsny': 'seharusnya',
                    'hrsnya': 'seharusnya',
                    'hrus': 'harus',
                    'hsl': 'hasil',
                    'hti': 'hati',
                    'huah': 'wah',
                    'huakbar': 'allahu akbar',
                    'hub': 'hubung',
                    'hubunganya': 'hubungannya',
                    'huehue': 'hehe',
                    'hukumanny': 'hukumannya',
                    'hums': 'rumah',
                    'humz': 'rumah',
                    'huum': 'iya',
                    'huwallohu': 'allahu',
                    'hy': 'hanya',
                    'idelete': 'hapus',
                    'idup': 'hidup',
                    'igat': 'ingat',
                    'ihlas': 'ikhlas',
                    'ijo': 'hijau',
                    'iket': 'ikat',
                    'iki': 'ini',
                    'iklas': 'ikhlas',
                    'iku': 'ikut',
                    'ikutikutan': 'ikut ikutan',
                    'ikutin': 'ikuti',
                    'ilah': 'lah',
                    'ilang': 'hilang',
                    'ilangnya': 'hilangnya',
                    'imbau': 'himbau',
                    'imembela': 'saya membela',
                    'imwith': 'saya dengan',
                    'imwithahok': 'saya dengan ahok',
                    'ind': 'indonesia',
                    'indakk': 'tidak',
                    'independen': 'bebas',
                    'indo': 'indonesia',
                    'indonesian': 'indonesia',
                    'inget': 'ingat',
                    'ingetin': 'ingatkan',
                    'ingnikan': 'menginginkan',
                    'ingt': 'ingat',
                    'inibarujakarta': 'ini baru jakarta',
                    'inideh': 'ini deh',
                    'innocense': 'tidak bersalah',
                    'inoleran': 'tidak toleran',
                    'insallah': 'insyaallah',
                    'insha': 'insya',
                    'insyaa': 'insya',
                    'insyaallah': 'insyaallah',
                    'insyaalloh': 'insyaallah',
                    'insyallah': 'insyaallah',
                    'internationally': 'international',
                    'isa': 'bisa',
                    'iso': 'bisa'}  # Mapping kata alay

abusive = ['alay',
           'ampas',
           'buta',
           'keparat',
           'anjing',
           'anjir',
           'babi',
           'bacot',
           'bajingan',
           'banci',
           'bandot',
           'buaya',
           'bangkai',
           'bangsat',
           'bego',
           'bejat',
           'bencong',
           'berak',
           'bisu',
           'celeng',
           'jancuk',
           'bodoh',
           'berengsek',
           'budek',
           'burik',
           'jamban',
           'cocot',
           'congor',
           'culun',
           'cupu',
           'dongok',
           'dungu',
           'edan',
           'tai',
           'ngewe',
           'geblek',
           'gembel',
           'gila',
           'goblok',
           'iblis',
           'idiot',
           'jablay',
           'jembud',
           'jembut',
           'jijik',
           'kacrut',
           'kafir',
           'modar',
           'kampang',
           'kampret',
           'kampungan',
           'kimak',
           'kontol',
           'kunti',
           'tuyul',
           'kunyuk',
           'mampus',
           'memek',
           'monyet',
           'najis',
           'nete',
           'ngentot',
           'noob',
           'pecun',
           'perek',
           'sampah',
           'sarap',
           'setan',
           'silit',
           'bokong',
           'sinting',
           'sompret',
           'sontoloyo',
           'terkutuk',
           'titit',
           'pantat',
           'tolol',
           'udik',
           'antek',
           'asing',
           'ateis',
           'sitip',
           'autis',
           'picek',
           'ayam kampus',
           'bani kotak',
           'bispak',
           'bisyar',
           'bokep',
           'bong',
           'cacat',
           'cct',
           'cebong',
           'taplak',
           'cungkring',
           'gay',
           'gembrot',
           'gendut',
           'hina',
           'homo',
           'komunis',
           'koreng',
           'krempeng',
           'lengser',
           'lesbi',
           'lgbt',
           'lonte',
           'mucikari',
           'munafik',
           'ngaceng',
           'nista',
           'kejam',
           'onta',
           'panastak',
           'panasbung',
           'bani',
           'pasukan nasi',
           'porno',
           'seks',
           'rejim',
           'rezim',
           'sange',
           'serbet',
           'sipit',
           'transgender']  # Daftar kata abusive

# Clean the text by removing stopwords


def cleansing_stopwords(text):
    text = ' '.join(word for word in text.split(
        ' ') if word.lower() not in stop_words)
    return text.lower()

# Clean the text using regex


def cleansing_byusingregex(text):
    text = re.sub('-', ' ', text)  # Remove tanda strip
    text = re.sub('[^0-9a-zA-Z]+', ' ', text)  # Remove all symbols
    text = re.sub('  +', ' ', text)  # Remove extra spaces
    text = re.sub('\n', ' ', text)  # Remove every '\n'
    text = re.sub('#', ' ', text)  # Remove every retweet symbol
    text = re.sub('user', ' ', text)  # Remove every username
    text = re.sub('USER', ' ', text)  # Remove every username
    # Remove every URL
    text = re.sub(
        '((www\.[^\s]+)|(https?://[^\s]+)|(http?://[^\s]+))', ' ', text)
    text = re.sub('[\d\.]+', '', text)  # Remove numbers
    text = re.sub('!', ' ', text)
    text = re.sub(r'[\t\s]+', ' ', text)  # Menghapus spasi berlebih
    text = re.sub(r'[^\w\s]', '', text)  # Menghapus tanda baca
    return text.lower()

# Change words using the mapping and remove abusive words


def change_word(text):
    # Cleansing Kata Alay
    text = ' '.join([df_new_kamusalay[word]
                    if word in df_new_kamusalay else word for word in text.split(' ')])
    # Cleansing Kata Abusive
    text = ' '.join(
        ['***' if word in abusive else word for word in text.split(' ')])
    # Menghapus kata-kata yang hanya terdiri dari angka
    text = ' '.join(word for word in text.split(' ') if not word.isdigit())

    # Menghapus kata-kata yang hanya terdiri dari satu karakter
    text = ' '.join(word for word in text.split(' ') if len(word) > 1)
    text = text.strip()  # Remove leading and trailing spaces
    return text.lower()


# Preprocessing function


def text_preprocessing(text):
    text = cleansing_stopwords(text)  # Remove stopwords
    text = cleansing_byusingregex(text)
    text = change_word(text)  # Change words and remove abusive words
    return text.lower()
